@@ -13,10 +13,7 @@ import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/pipeline",
-    "0.0.96",
-    __name__[0:-6],
-    "pipeline@0.0.96.jsii.tgz",
+    "@aws-prototyping-sdk/pipeline", "0.1.0", __name__[0:-6], "pipeline@0.1.0.jsii.tgz"
 )
 
 __all__ = [
